PAWpySeed: pawpyseed.core Namespace Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Namespace Members

Namespaces
pawpyseed.core Namespace Reference

## Namespaces
| gaunt
| momentum
| noncollinear
| projector
| Defines the Projector class for evaluating AE and PS projection operators.
| quad_check
| quadrature
| rayleigh
| symmetry
| Utilities related to symmetry of the crystal structure, namely finding symmetrically identical k-points and the space group operators that map between them.
| test_radial
| utils
| Miscellaneous utilities file for the Python portion of the code.
| wavefunction
| Base class containing Python classes for parsing files and storing and analyzing wavefunction data.